@@ -71,10 +71,13 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     KAboutData aboutData(QStringLiteral("dolphin"), i18n("Dolphin"), QStringLiteral(DOLPHIN_VERSION_STRING),
                          i18nc("@title", "File Manager"),
                          KAboutLicense::GPL,
-                         i18nc("@info:credit", "(C) 2006-2016 Peter Penz, Frank Reininghaus, and Emmanuel Pescosta"));
+                         i18nc("@info:credit", "(C) 2006-2018 Peter Penz, Frank Reininghaus, Emmanuel Pescosta and Elvis Angelaccio"));
     aboutData.setHomepage(QStringLiteral("http://dolphin.kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Elvis Angelaccio"),
+                        i18nc("@info:credit", "Maintainer (since 2018) and developer"),
+                        QStringLiteral("elvis.angelaccio@kde.org"));
     aboutData.addAuthor(i18nc("@info:credit", "Emmanuel Pescosta"),
-                        i18nc("@info:credit", "Maintainer (since 2014) and developer"),
+                        i18nc("@info:credit", "Maintainer (2014-2018) and developer"),
                         QStringLiteral("emmanuelpescosta099@gmail.com"));
     aboutData.addAuthor(i18nc("@info:credit", "Frank Reininghaus"),
                         i18nc("@info:credit", "Maintainer (2012-2014) and developer"),
@@ -144,7 +147,6 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     }
 
     DolphinMainWindow* mainWindow = new DolphinMainWindow();
-    mainWindow->setAttribute(Qt::WA_DeleteOnClose);
 
     if (parser.isSet(QStringLiteral("select"))) {
         mainWindow->openFiles(urls, splitView);
