@@ -20,21 +20,16 @@
 
 #include "phononwidget.h"
 
+#include <KIconLoader>
+#include <KLocalizedString>
 #include <Phonon/AudioOutput>
-#include <Phonon/Global>
 #include <Phonon/MediaObject>
 #include <Phonon/SeekSlider>
 #include <Phonon/VideoWidget>
 
-#include <QVBoxLayout>
-#include <QHBoxLayout>
 #include <QShowEvent>
 #include <QToolButton>
-#include <QDialog>
-#include <QIcon>
-#include <KIconLoader>
-#include <QUrl>
-#include <KLocalizedString>
+#include <QVBoxLayout>
 
 class EmbeddedVideoPlayer : public Phonon::VideoWidget
 {
@@ -52,7 +47,7 @@ class EmbeddedVideoPlayer : public Phonon::VideoWidget
             updateGeometry();
         }
 
-        QSize sizeHint() const Q_DECL_OVERRIDE
+        QSize sizeHint() const override
         {
             return m_sizeHint.isValid() ? m_sizeHint : Phonon::VideoWidget::sizeHint();
         }
@@ -172,7 +167,7 @@ void PhononWidget::stateChanged(Phonon::State newstate)
             m_videoPlayer->hide();
         }
         emit hasVideoChanged(false);
-        // fall through
+        Q_FALLTHROUGH();
     default:
         m_stopButton->hide();
         m_playButton->show();
