@@ -20,11 +20,11 @@
 #ifndef TOOLTIPMANAGER_H
 #define TOOLTIPMANAGER_H
 
+#include <KFileItem>
+
 #include <QObject>
 #include <QRect>
 
-#include <KFileItem>
-
 class DolphinFileMetaDataWidget;
 class KToolTipWidget;
 class QTimer;
@@ -43,7 +43,7 @@ class ToolTipManager : public QObject
 
 public:
     explicit ToolTipManager(QWidget* parent);
-    virtual ~ToolTipManager();
+    ~ToolTipManager() override;
 
     /**
      * Triggers the showing of the tooltip for the item \p item
@@ -58,6 +58,13 @@ public:
      */
     void hideToolTip();
 
+signals:
+    /**
+     * Is emitted when the user clicks a tag or a link
+     * in the metadata widget.
+     */
+    void urlActivated(const QUrl& url);
+
 private slots:
     void startContentRetrieval();
     void setPreviewPix(const KFileItem& item, const QPixmap& pix);
